# ubiquerg

[![Build Status](https://travis-ci.org/pepkit/ubiquerg.svg?branch=master)](https://travis-ci.org/pepkit/ubiquerg)
[![Coverage Status](https://coveralls.io/repos/github/pepkit/ubiquerg/badge.svg?branch=master)](https://coveralls.io/github/pepkit/ubiquerg?branch=master)
[![PEP compatible](http://pepkit.github.io/img/PEP-compatible-green.svg)](http://pepkit.github.io)

Tools for work (erg) everywhere (ubique)

